<?php
namespace Inti\Gath\Wp\Plugin;

use Inti\Gath\Model\Hydrator\Strategy\ProductIdStrategy;
use Inti\Gath\Model\Hydrator\Strategy\TireIdStrategy;
use Inti\Gath\Model\Repository\ProductPriceRepository;
use Inti\Gath\Model\Repository\ProductRepository;

/**
 * Class GathPrices
 *
 * @package Inti\Gath\Wp\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-gath
 */
final class GathPrices extends GathMetadata
{
    /** @var ProductPriceRepository */
    private $prices;
    /** @var ProductRepository */
    private $products;
    /** @var string */
    protected $metaType = 'post';
    /** @var string[] */
    protected $metaKeys = [
        '_price',
        '_regular_price',
        '_sale_price',
        '_sale_price_dates_from',
        '_sale_price_dates_to',
    ];

    /**
     * Konstruktor.
     *
     * @param ProductPriceRepository $prices
     * @param ProductRepository $products
     */
    public function __construct(ProductPriceRepository $prices, ProductRepository $products)
    {
        $this->prices = $prices;
        $this->products = $products;
    }

    /**
     * @param int $objectId
     * @return array
     */
    protected function get_metadata_by_id(int $objectId): array
    {
        if ($objectId > TireIdStrategy::ID_OFFSET) {
            $productPrice = $this->prices->getByProductSku([], [$objectId])[0] ?? null;
        } else if ($objectId > ProductIdStrategy::ID_OFFSET) {
            $product = $this->products->getById($objectId);
            $productPrice = $this->prices->getByProductSku([$product->getSku()])[0] ?? null;
        } else {
            $sku = get_post_meta($objectId, '_sku', true);
            $productPrice = $this->prices->getByProductSku([$sku])[0] ?? null;
        }

        return isset($productPrice) ? [
            '_price' => $productPrice->getPrice() ?: '',
            '_regular_price' => $productPrice->getRegularPrice() ?: '',
            '_sale_price' => $productPrice->getSalePrice() ?: '',
            '_sale_price_dates_from' => '',
            '_sale_price_dates_to' => '',
        ] : [];
    }
}
